#
# spec file for package stax2-api
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           stax2-api
Version:        4.2.1
Release:        3.1
Summary:        Experimental API extending basic StAX implementation
License:        BSD-2-Clause
Group:          Development/Libraries/Java
URL:            http://wiki.fasterxml.com/WoodstoxStax2
Source0:        https://github.com/FasterXML/%{name}/archive/%{name}-%{version}.tar.gz
Source1:        %{name}-build.xml
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local >= 6
BuildArch:      noarch

%description
StAX2 is an experimental API that is intended to extend
basic StAX specifications in a way that allows implementations
to experiment with features before they end up in the actual
StAX specification (if they do). As such, it is intended
to be freely implementable by all StAX implementations same way
as StAX, but without going through a formal JCP process.

%package javadoc
Summary:        API documentation for %{name}
Group:          Documentation/HTML

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q -n %{name}-%{name}-%{version}
cp %{SOURCE1} build.xml

%build
ant jar javadoc

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}
install -pm 0644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}.jar
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/%{name}.pom
%add_maven_depmap %{name}.pom %{name}.jar
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}
cp -r target/site/apidocs %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles

%files javadoc
%{_javadocdir}/%{name}

%changelog
* Fri Mar 28 2025 Fridrich Strba <fstrba@suse.com>
- Rewrite to use Ant to build. This prevents potential cycles with
  upcoming Maven 4
* Sat Sep  9 2023 Fridrich Strba <fstrba@suse.com>
- Reproducible builds: use SOURCE_DATE_EPOCH for timestamp
* Fri Aug 25 2023 Fridrich Strba <fstrba@suse.com>
- Update to version 4.2.1
  * 4.2.1 (14-May-2020)
    + #12: Fix to XML declaration write when 'standaloneSet' is
    specified
  * 4.2 (13-Mar-2019)
    + #15: Add Java 9+ module info using Moditect
    + Increase visibility of some of methods of
    'Stax2EventReaderImpl'
  * 4.1 (28-Mar-2018)
    + Add 'Automatic-Module-Name' for Java 9
    + Upgrade JDK baseline requirement Java 6 (from Java 5);
    + remove 'stax-api' dependency (since bundled on Java 6)
* Wed Mar 23 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 8
* Sun Nov 24 2019 Fridrich Strba <fstrba@suse.com>
- Specify maven.compiler.release to fix build with jdk9+ and newer
  maven-javadoc-plugin
* Thu Nov 21 2019 Fridrich Strba <fstrba@suse.com>
- Use default maven-compiler-plugin configuration to avoid 1.5
  as source/target levels
* Fri May  3 2019 Fridrich Strba <fstrba@suse.com>
- Intial packaging of stax2-api 4.0.0
